segmentedControlWidth property
Width of the segmented control in logical pixels. If null, the control sizes itself based on content.
Implementation
final double? segmentedControlWidth;
Width of the segmented control in logical pixels. If null, the control sizes itself based on content.
final double? segmentedControlWidth;