CNSheet class

Backward compatibility class for CNSheet

Delegates to CNNativeSheet for native rendering. This maintains API compatibility with existing code.

Constructors

CNSheet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required dynamic context, String? title, String? message, List<CNSheetItem> items = const [], List<CNSheetDetent> detents = const [CNSheetDetent.large], bool prefersGrabberVisible = true, bool isModal = true, bool prefersEdgeAttachedInCompactHeight = false, bool widthFollowsPreferredContentSizeWhenEdgeAttached = false, double? preferredCornerRadius, dynamic itemBackgroundColor, dynamic itemTextColor, dynamic itemTintColor, void onItemSelected(int index)?}) Future<int?>
Shows a native sheet (delegates to CNNativeSheet)
showWithCustomHeader({required dynamic context, required String title, String? message, List<CNSheetItem> items = const [], List<CNSheetItemRow> itemRows = const [], List<CNSheetInlineActions> inlineActions = const [], List<CNSheetDetent> detents = const [CNSheetDetent.large], bool prefersGrabberVisible = true, bool isModal = true, bool prefersEdgeAttachedInCompactHeight = false, bool widthFollowsPreferredContentSizeWhenEdgeAttached = false, double? preferredCornerRadius, double? headerTitleSize, dynamic headerTitleWeight, dynamic headerTitleColor, String headerTitleAlignment = 'left', String? subtitle, double? subtitleSize, dynamic subtitleColor, double? headerHeight, dynamic headerBackgroundColor, bool showHeaderDivider = true, dynamic headerDividerColor, String closeButtonPosition = 'trailing', String closeButtonIcon = 'xmark', double? closeButtonSize, dynamic closeButtonColor, dynamic itemBackgroundColor, dynamic itemTextColor, dynamic itemTintColor, void onInlineActionSelected(int rowIndex, int actionIndex)?, void onItemSelected(int index)?, void onItemRowSelected(int rowIndex, int itemIndex)?}) Future<int?>
Shows a sheet with custom header (delegates to CNNativeSheet)
showWithCustomHeaderUiKitView({required dynamic context, required String title, required Widget builder(BuildContext), List<CNSheetDetent> detents = const [CNSheetDetent.large], bool prefersGrabberVisible = true, bool isModal = false, bool prefersEdgeAttachedInCompactHeight = false, bool widthFollowsPreferredContentSizeWhenEdgeAttached = false, double? preferredCornerRadius, double? headerTitleSize, dynamic headerTitleWeight, dynamic headerTitleColor, double? headerHeight, dynamic headerBackgroundColor, bool showHeaderDivider = true, dynamic headerDividerColor, String closeButtonPosition = 'trailing', String closeButtonIcon = 'xmark', double? closeButtonSize, dynamic closeButtonColor}) Future<void>
Shows a native sheet with custom Flutter widget content using UiKitView (delegates to CNNativeSheet)
showWithCustomHeaderWidget({required dynamic context, required Widget headerBuilder(BuildContext), required Widget contentBuilder(BuildContext), List<CNSheetDetent> detents = const [CNSheetDetent.large], bool prefersGrabberVisible = true, bool isModal = false, bool prefersEdgeAttachedInCompactHeight = false, bool widthFollowsPreferredContentSizeWhenEdgeAttached = false, double? preferredCornerRadius, double? headerHeight, dynamic headerBackgroundColor, bool showHeaderDivider = true, dynamic headerDividerColor, VoidCallback? onClose}) Future<void>
Shows a native sheet with custom Flutter widget header and content (delegates to CNNativeSheet)