badgeColor property
Background color for the badge. If null, uses the platform default badge color (typically red).
Implementation
final Color? badgeColor;
Background color for the badge. If null, uses the platform default badge color (typically red).
final Color? badgeColor;