isSearchTab property
Whether this tab is a search tab
Only one tab should be marked as a search tab. When selected, the tab bar will transform into a search bar on iOS 26+.
Implementation
final bool isSearchTab;
Whether this tab is a search tab
Only one tab should be marked as a search tab. When selected, the tab bar will transform into a search bar on iOS 26+.
final bool isSearchTab;