CNSheetItem class
An item to display in a native sheet
Constructors
- CNSheetItem({required String? title, String? icon, bool dismissOnTap = true, Color? backgroundColor, Color? textColor, Color? iconColor, double? height, double? fontSize, double? iconSize, FontWeight? fontWeight, double? iconLabelSpacing})
-
Creates a simple sheet item with title and optional icon.
This will be rendered natively using UISheetPresentationController.
const
Properties
- backgroundColor → Color?
-
final
- dismissOnTap → bool
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- icon → String?
-
final
- iconColor → Color?
-
final
- iconLabelSpacing → double?
-
final
- iconSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited