segmentedControlTint property
Tint color for the selected segment background in the segmented control. This is the background color of the selected segment. If null, uses the navigation bar's tint color or system default.
Implementation
final Color? segmentedControlTint;